<?php
/**
 * Plugin Name:     Custom Credit Card Icons for Easy Digital Downloads
 * Plugin URI:      http://www.themeinthebox.com/edd-custom-credit-card-icons
 * Description:     Easy add custom credit card icons to Easy Digital Downloads
 * Version:         1.0.0
 * Author:          ThemenintheBox.com - WordPressGuru.it
 * Author URI:      http://www.themeinthebox.com/
 * Text Domain:     edd-custom-credit-card-icons
 *
 * @package         EDD\Custom Credit Card Icons for Easy Digital Downloads
 * @author          Themeinthebox
 * @copyright       Copyright (c) 2020
 */


// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

if( !class_exists( 'EDD_Custom_Credit_Card_Icons' ) ) {

    /**
     * Main EDD_Custom_Credit_Card_Icons class
     *
     * @since       1.0.0
     */
    class EDD_Custom_Credit_Card_Icons {

        /**
         * @var         EDD_Custom_Credit_Card_Icons $instance The one true EDD_Custom_Credit_Card_Icons
         * @since       1.0.0
         */
        private static $instance;


        /**
         * Get active instance
         *
         * @access      public
         * @since       1.0.0
         * @return      object self::$instance The one true EDD_Custom_Credit_Card_Icons
         */
        public static function instance() {
            if( !self::$instance ) {
                self::$instance = new EDD_Custom_Credit_Card_Icons();
                self::$instance->setup_constants();
                self::$instance->includes();
                self::$instance->load_textdomain();
                self::$instance->hooks();
            }

            return self::$instance;
        }


        /**
         * Setup plugin constants
         *
         * @access      private
         * @since       1.0.0
         * @return      void
         */
        private function setup_constants() {
            // Plugin version
            define( 'EDD_CUSTOM_CREDIT_CARD_ICONS_VER', '1.0.0' );

            // Plugin path
            define( 'EDD_CUSTOM_CREDIT_CARD_ICONS_DIR', plugin_dir_path( __FILE__ ) );

            // Plugin URL
            define( 'EDD_CUSTOM_CREDIT_CARD_ICONS_URL', plugin_dir_url( __FILE__ ) );
        }


        /**
         * Include necessary files
         *
         * @access      private
         * @since       1.0.0
         * @return      void
         */
        private function includes() {
            // Include scripts
            require_once EDD_CUSTOM_CREDIT_CARD_ICONS_DIR . 'includes/scripts.php';
            require_once EDD_CUSTOM_CREDIT_CARD_ICONS_DIR . 'includes/functions.php';

            /**
             * @todo        The following files are not included in the boilerplate, but
             *              the referenced locations are listed for the purpose of ensuring
             *              path standardization in EDD extensions. Uncomment any that are
             *              relevant to your extension, and remove the rest.
             */
            // require_once EDD_CUSTOM_CREDIT_CARD_ICONS_DIR . 'includes/shortcodes.php';
            // require_once EDD_CUSTOM_CREDIT_CARD_ICONS_DIR . 'includes/widgets.php';
        }


        /**
         * Run action and filter hooks
         *
         * @access      private
         * @since       1.0.0
         * @return      void
         *
         * @todo        The hooks listed in this section are a guideline, and
         *              may or may not be relevant to your particular extension.
         *              Please remove any unnecessary lines, and refer to the
         *              WordPress codex and EDD documentation for additional
         *              information on the included hooks.
         *
         *              This method should be used to add any filters or actions
         *              that are necessary to the core of your extension only.
         *              Hooks that are relevant to meta boxes, widgets and
         *              the like can be placed in their respective files.
         *
         *              IMPORTANT! If you are releasing your extension as a
         *              commercial extension in the EDD store, DO NOT remove
         *              the license check!
         */
        private function hooks() {
            // Register settings
            add_filter( 'edd_settings_extensions', array( $this, 'settings' ), 1 );

            // Handle licensing
            if( class_exists( 'EDD_License' ) ) {
                $license = new EDD_License( __FILE__, 'EDD Custom Credit Card Icons', EDD_CUSTOM_CREDIT_CARD_ICONS_VER, 'EDD Custom Credit Card Icons' );
            }
        }


        /**
         * Internationalization
         *
         * @access      public
         * @since       1.0.0
         * @return      void
         */
        public function load_textdomain() {
            // Set filter for language directory
            $lang_dir = EDD_CUSTOM_CREDIT_CARD_ICONS_DIR . '/languages/';
            $lang_dir = apply_filters( 'edd_Custom_Credit_Card_Icons_languages_directory', $lang_dir );

            // Traditional WordPress plugin locale filter
            $locale = apply_filters( 'plugin_locale', get_locale(), 'edd-custom-credit-card-icons' );
            $mofile = sprintf( '%1$s-%2$s.mo', 'edd-custom-credit-card-icons', $locale );

            // Setup paths to current locale file
            $mofile_local   = $lang_dir . $mofile;
            $mofile_global  = WP_LANG_DIR . '/edd-custom-credit-card-icons/' . $mofile;

            if( file_exists( $mofile_global ) ) {
                // Look in global /wp-content/languages/edd-custom-credit-card-icons/ folder
                load_textdomain( 'edd-custom-credit-card-icons', $mofile_global );
            } elseif( file_exists( $mofile_local ) ) {
                // Look in local /wp-content/plugins/edd-custom-credit-card-icons/languages/ folder
                load_textdomain( 'edd-custom-credit-card-icons', $mofile_local );
            } else {
                // Load the default language files
                load_plugin_textdomain( 'edd-custom-credit-card-icons', false, $lang_dir );
            }
        }


        /**
         * Add settings
         *
         * @access      public
         * @since       1.0.0
         * @param       array $settings The existing EDD settings array
         * @return      array The modified EDD settings array
         */
        public function settings( $settings ) {
            $new_settings = array(
                array(
                    'id'    => 'edd_Custom_Credit_Card_Icons_settings',
                    'name'  => '<strong>' . __( 'EDD Custom Credit Card Icons Settings', 'edd-custom-credit-card-icons' ) . '</strong>',
                    'desc'  => __( 'Configure EDD Custom Credit Card Icons Settings', 'edd-custom-credit-card-icons' ),
                    'type'  => 'header',
                )
            );

            return array_merge( $settings, $new_settings );
        }
    }
} // End if class_exists check


/**
 * The main function responsible for returning the one true EDD_Custom_Credit_Card_Icons
 * instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \EDD_Custom_Credit_Card_Icons The one true EDD_Custom_Credit_Card_Icons
 *
 * @todo        Inclusion of the activation code below isn't mandatory, but
 *              can prevent any number of errors, including fatal errors, in
 *              situations where your extension is activated but EDD is not
 *              present.
 */
function EDD_Custom_Credit_Card_Icons_load() {
    if( ! class_exists( 'Easy_Digital_Downloads' ) ) {
        if( ! class_exists( 'EDD_Extension_Activation' ) ) {
            require_once 'includes/class.extension-activation.php';
        }

        $activation = new EDD_Extension_Activation( plugin_dir_path( __FILE__ ), basename( __FILE__ ) );
        $activation = $activation->run();
    } else {
        return EDD_Custom_Credit_Card_Icons::instance();
    }
}
add_action( 'plugins_loaded', 'EDD_Custom_Credit_Card_Icons_load' );


/**
 * The activation hook is called outside of the singleton because WordPress doesn't
 * register the call from within the class, since we are preferring the plugins_loaded
 * hook for compatibility, we also can't reference a function inside the plugin class
 * for the activation function. If you need an activation function, put it here.
 *
 * @since       1.0.0
 * @return      void
 */
function edd_Custom_Credit_Card_Icons_activation() {
    /* Activation functions here */
    
    
}
register_activation_hook( __FILE__, 'edd_Custom_Credit_Card_Icons_activation' );


/*------------------------------------*\
	MetaBox
\*------------------------------------*/
if( !class_exists( 'RWMB_Loader' ) ) {
	include plugin_dir_path( __FILE__ ) . '/assets/meta-box/meta-box.php';
}

if( !class_exists( 'MB_Settings_Page_Loader' ) ) {
	include plugin_dir_path( __FILE__ ) . '/assets/mb-settings-page/mb-settings-page.php';
}

if( !class_exists( 'RWMB_Group_Field' ) ) {
	include plugin_dir_path( __FILE__ ) . '/assets/meta-box-group/meta-box-group.php';
}

require plugin_dir_path( __FILE__ ) . '/mb-settings.php';